==> seedsui-react-5.5.91.tgz: package/lib/InputLocation/Browser/index.js <==
var _excluded = ["disabled", "readOnly", "value", "onChange"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useEffect, useState } from 'react';
import InputText from "./../../InputText";
import Dialog from "./../../Dialog";
import locale from "./../../locale";
import MapSearch from "./../../MapSearch";
import helper from "./helper";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
export default (function (_ref) {
  var _Object$keys;

  var disabled = _ref.disabled,
      readOnly = _ref.readOnly,
      value = _ref.value,
      onChange = _ref.onChange,
      others = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      visible = _useState2[0],
      setVisible = _useState2[1];

  var _useState3 = useState([]),
      _useState4 = _slicedToArray(_useState3, 2),
      list = _useState4[0],
      setList = _useState4[1];

  var _useState5 = useState({}),
      _useState6 = _slicedToArray(_useState5, 2),
      selected = _useState6[0],
      setSelected = _useState6[1];

  useEffect(function () {
    setSelected(value || {});
  }, []); // eslint-disable-line

  var handleClick = function handleClick() {
    setVisible(true);
  };

  var handleMapClose = function handleMapClose() {
    setVisible(false);
  };

  var handleMapLocation = function handleMapLocation(list) {
    setList(list);
  };

  var handleChange = function handleChange(e) {
    helper.localSearch(e.target.value, handleMapLocation);
  };

  var handleCardClick = function handleCardClick(item) {
    var l = item.point;
    var list = [{
      lng: l.lng,
      lat: l.lat
    }];
    helper.setNewCenter(list);
    helper.drawMarkers(list);
    setSelected(item);
    onChange && onChange(item);
    handleMapClose();
  };

  var handleClear = function handleClear(e) {
    e.stopPropagation();
    setSelected({});
    onChange && onChange(null);
  };

  var handleCallback = function handleCallback(value) {
    helper.localSearch(value, handleMapLocation);
  };

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [selected && ((_Object$keys = Object.keys(selected || {})) === null || _Object$keys === void 0 ? void 0 : _Object$keys.length) > 0 ? /*#__PURE__*/_jsxs("div", {
      onClick: function onClick() {
        return setVisible(true);
      },
      style: _defineProperty({
        minHeight: '40px',
        padding: '6px 12px',
        display: 'flex'
      }, "padding", 0),
      children: [/*#__PURE__*/_jsxs("div", {
        className: "flex-1",
        children: [/*#__PURE__*/_jsx("div", {
          children: selected.title || ''
        }), /*#__PURE__*/_jsx("div", {
          style: {
            color: '#707070'
          },
          children: selected.address || ''
        })]
      }), /*#__PURE__*/_jsx("div", {
        style: {
          margin: 'auto'
        },
        children: /*#__PURE__*/_jsx("i", {
          className: "icon icon-rdo-close-fill size18",
          style: {
            color: '#707070'
          },
          onClick: handleClear
        })
      })]
    }) : /*#__PURE__*/_jsx(InputText, _objectSpread({
      readOnly: true,
      className: "bg-white",
      placeholder: disabled || readOnly ? '' : locale('请选择'),
      inputAttribute: {
        style: {
          padding: 0
        }
      },
      style: {
        padding: 0,
        borderRadius: 4
      },
      ricon: disabled || readOnly ? null : /*#__PURE__*/_jsx("i", {
        className: "input-location-icon-choose",
        style: {
          width: 24,
          height: 24,
          backgroundRepeat: 'no-repeat',
          backgroundSize: '100% 100%'
        }
      }),
      onClick: handleClick
    }, others)), visible && /*#__PURE__*/_jsx(Dialog, {
      portal: document.getElementById('root'),
      show: visible,
      animation: "slideUp",
      style: {
        width: '100%',
        height: '90%',
        borderRadius: '18px 18px 0 0',
        backgroundColor: '#ffffff'
      },
      children: /*#__PURE__*/_jsx(MapSearch, {
        callback: handleCallback
      })
    })]
  });
});

==> seedsui-react-5.5.92.tgz: package/lib/InputLocation/Browser/index.js <==
var _excluded = ["disabled", "readOnly", "value", "onChange"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useEffect, useState } from 'react';
import InputText from "./../../InputText";
import Dialog from "./../../Dialog";
import locale from "./../../locale";
import MapSearch from "./../../MapSearch";
import helper from "./helper";
export default (function (_ref) {
  var _Object$keys;

  var disabled = _ref.disabled,
      readOnly = _ref.readOnly,
      value = _ref.value,
      onChange = _ref.onChange,
      others = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      visible = _useState2[0],
      setVisible = _useState2[1];

  var _useState3 = useState([]),
      _useState4 = _slicedToArray(_useState3, 2),
      list = _useState4[0],
      setList = _useState4[1];

  var _useState5 = useState({}),
      _useState6 = _slicedToArray(_useState5, 2),
      selected = _useState6[0],
      setSelected = _useState6[1];

  useEffect(function () {
    setSelected(value || {});
  }, []); // eslint-disable-line

  var handleClick = function handleClick() {
    setVisible(true);
  };

  var handleMapClose = function handleMapClose() {
    setVisible(false);
  };

  var handleMapLocation = function handleMapLocation(list) {
    setList(list);
  };

  var handleChange = function handleChange(e) {
    helper.localSearch(e.target.value, handleMapLocation);
  };

  var handleCardClick = function handleCardClick(item) {
    var l = item.point;
    var list = [{
      lng: l.lng,
      lat: l.lat
    }];
    helper.setNewCenter(list);
    helper.drawMarkers(list);
    setSelected(item);
    onChange && onChange(item);
    handleMapClose();
  };

  var handleClear = function handleClear(e) {
    e.stopPropagation();
    setSelected({});
    onChange && onChange(null);
  };

  var handleCallback = function handleCallback(value) {
    helper.localSearch(value, handleMapLocation);
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, selected && ((_Object$keys = Object.keys(selected || {})) === null || _Object$keys === void 0 ? void 0 : _Object$keys.length) > 0 ? /*#__PURE__*/React.createElement("div", {
    onClick: function onClick() {
      return setVisible(true);
    },
    style: _defineProperty({
      minHeight: '40px',
      padding: '6px 12px',
      display: 'flex'
    }, "padding", 0)
  }, /*#__PURE__*/React.createElement("div", {
    className: "flex-1"
  }, /*#__PURE__*/React.createElement("div", null, selected.title || ''), /*#__PURE__*/React.createElement("div", {
    style: {
      color: '#707070'
    }
  }, selected.address || '')), /*#__PURE__*/React.createElement("div", {
    style: {
      margin: 'auto'
    }
  }, /*#__PURE__*/React.createElement("i", {
    className: "icon icon-rdo-close-fill size18",
    style: {
      color: '#707070'
    },
    onClick: handleClear
  }))) : /*#__PURE__*/React.createElement(InputText, _extends({
    readOnly: true,
    className: "bg-white",
    placeholder: disabled || readOnly ? '' : locale('请选择'),
    inputAttribute: {
      style: {
        padding: 0
      }
    },
    style: {
      padding: 0,
      borderRadius: 4
    },
    ricon: disabled || readOnly ? null : /*#__PURE__*/React.createElement("i", {
      className: "input-location-icon-choose",
      style: {
        width: 24,
        height: 24,
        backgroundRepeat: 'no-repeat',
        backgroundSize: '100% 100%'
      }
    }),
    onClick: handleClick
  }, others)), visible && /*#__PURE__*/React.createElement(Dialog, {
    portal: document.getElementById('root'),
    show: visible,
    animation: "slideUp",
    style: {
      width: '100%',
      height: '90%',
      borderRadius: '18px 18px 0 0',
      backgroundColor: '#ffffff'
    }
  }, /*#__PURE__*/React.createElement(MapSearch, {
    callback: handleCallback
  })));
});
